﻿using System;
using System.Collections.Generic;
using System.IO;
using System.Linq;
using System.Reflection;
using System.Text;
using System.Windows.Forms;
using Autodesk.AutoCAD.ApplicationServices;
using Autodesk.AutoCAD.Customization;
using Autodesk.AutoCAD.DatabaseServices;
using Autodesk.AutoCAD.Geometry;
using Autodesk.AutoCAD.Runtime;
using AcadApp = Autodesk.AutoCAD.ApplicationServices.Application;

[assembly: CommandClass(typeof(CuiTestLibrary.Commands))]
namespace CuiTestLibrary
{
    public class Commands : IExtensionApplication
    {
        [CommandMethod("CreateTestCuix")]
        public static void CreateTestCuix()
        {
            var editor = AcadApp.DocumentManager.MdiActiveDocument.Editor;

            try
            {
                var debugFolder          = Path.GetDirectoryName(Assembly.GetExecutingAssembly().Location);
                var customizationSection = new CustomizationSection();
                var menuGroup            = customizationSection.MenuGroup;
                var tab                  = customizationSection.AddNewTab("CuiTestTab");
                var panel                = tab.AddNewPanel("Panel");
                var row                  = panel.AddNewRibbonRow();

                menuGroup.Name           = "CuiTest";

                row.AddNewButton(
                    "BMP",
                    "BMP",
                    "SayBMP",
                    "BMP loaded from the resource DLL",
                    "IDB_CIRCLE16",
                    "IDB_CIRCLE32",
                    RibbonButtonStyle.LargeWithText);

                row.AddNewButton(
                    "ICO",
                    "ICO",
                    "SayICO",
                    "ICO loaded from the resource DLL",
                    "IDI_TRIANGLE16",
                    "IDI_TRIANGLE32",
                    RibbonButtonStyle.LargeWithText);

                // PNGs are not supported.
                // Transparency is only supported by ICO files.

                //row1.AddNewButton("PNG",
                //                  "PNG",
                //                  "SayPNG",
                //                  "PNG loaded from the resource DLL",
                //                  "IDB_SQUARE16",
                //                  "IDB_SQUARE32",
                //                  RibbonButtonStyle.LargeWithText);

                var fileName = Path.Combine(debugFolder, "CuiTest.cuix");

                File.Delete(fileName);

                customizationSection.SaveAs(fileName);
            }
            catch (System.Exception ex)
            {
                editor.WriteMessage(Environment.NewLine + ex.Message);
            }
        }

        #region Dummy commands

        [CommandMethod("SayBMP")]
        public static void SayBMP()
        {
            MessageBox.Show("BMP");
        }

        [CommandMethod("SayICO")]
        public static void SayICO()
        {
            MessageBox.Show("ICO");
        }

        [CommandMethod("SayPNG")]
        public static void SayPNG()
        {
            MessageBox.Show("PNG");
        }

        #endregion

        #region IExtensionApplication

        public void Initialize()
        {
        }

        public void Terminate()
        {
        }

        #endregion
    }
}
